<?php

namespace HCM\AVL\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response\Notification;
use HCM\Util\HCMParameters;
use HCM\Util\Messages;

class CriterioResultadoController extends Crud {

    protected $criterioResultadoService;
    protected $dataSourceName;
    protected $dataSourceNameCrit = 'avl_criterioresultado';
    protected $dataSourceNameCritGet = 'getCriterioResultado';
    protected $dataSourceNameFaixa = 'avl_faixacriterioresultado';
    protected $dataSourceNameFaixaGet = 'getFaixaCritResult';
    
    protected $parameterBagColumns = array('P_NRORG', 'P_NRORG_PADRAO', 'P_NRCRITERIORESUL');
   
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters ,\HCM\AVL\Services\CriterioResultadoService $criterioResultadoService){
        $this->parameterBag = $parameterBag;
        $this->hcmParameters = $hcmParameters;
        $this->CriterioResultadoService = $criterioResultadoService;
        parent::__construct($dataSourceManager);
    }

    public function getCriterioResultado(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceNameCritGet);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function getFaixaCritResult(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceNameFaixaGet);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function setCriterioResultado(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $this->dataSourceName = $this->dataSourceNameCrit;
            foreach ($request->getDataSet()->getRows() as &$row) {
                if (array_key_exists('NRCRITERIORESUL', $row)) {
                    if ($row['NRCRITERIORESUL'] === '') {
                        //$row['NRCRITERIORESUL'] = \Geral\Util\NovoCodigo::selectMax('CRITERIORESULT','NRCRITERIORESUL');
                        $row['NRCRITERIORESUL'] = \HCM\Util\NovoCodigo::geraCodigo( $row['NRORG'], 'CRITERIORESULT', 1, 12, true);
                    }
                } else {
                    //$row['NRCRITERIORESUL'] = \Geral\Util\NovoCodigo::selectMax('CRITERIORESULT','NRCRITERIORESUL');
                    $row['NRCRITERIORESUL'] = \HCM\Util\NovoCodigo::geraCodigo( $row['NRORG'], 'CRITERIORESULT', 1, 12, true);
                }
            }
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function setFaixaCritResult(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $this->dataSourceName = $this->dataSourceNameFaixa;
            foreach ($request->getDataSet()->getRows() as &$row) {
                if (array_key_exists('NRFAIXACRIRESUL', $row)) {
                    if ($row['NRFAIXACRIRESUL'] === '') {
                        //$row['NRFAIXACRIRESUL'] = \Geral\Util\NovoCodigo::selectMax('FAIXACRITRESULT','NRFAIXACRIRESUL');
                        $row['NRFAIXACRIRESUL'] = \HCM\Util\NovoCodigo::geraCodigo( $row['NRORG'], 'FAIXACRITRESULT', 1, 12, true);
                    }
                } else {
                    //$row['NRFAIXACRIRESUL'] = \Geral\Util\NovoCodigo::selectMax('FAIXACRITRESULT','NRFAIXACRIRESUL');
                    $row['NRFAIXACRIRESUL'] = \HCM\Util\NovoCodigo::geraCodigo( $row['NRORG'], 'FAIXACRITRESULT', 1, 12, true);
                }
            }
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteCriterioResultado(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $this->dataSourceName = $this->dataSourceNameCrit;
            $dataset = $request->getDataSet()->getRows();
            $dataset = $dataset[0];
            
            if($dataset["FAIXAS"] != null){
                //a função foi chamada para a exclusão das faixas relacionadas ao critério
                $this->CriterioResultadoService->deleteFaixasECriterio($dataset);
                $response->addNotification(new Notification(Messages::HCM03000_AVL_CRITERIO_APAGADO_SUCESSO, Notification::TYPE_SUCCESS));
            } else {
                //verifica a existência de faixas relacionadas ao criterio, caso não haja nenhuma realiza a exclusão
                //se houver faixas, elas são retornadas ao frontend que chama esse método novamente para a exclusão das faixas e posteriormente a exclusão do critério
                $faixas = $this->CriterioResultadoService->checkCriterioResultado($dataset);
                if($faixas){
                    $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message(Messages::HCM03000_AVL_FAIXA_VINCULADAS, DTO\Response\Message::TYPE_WARNING));
                    $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('faixas', $faixas));
                }else{
                    //caso o critério não tenha faixas inicialmente, ele é excluído diretamente 
                    $this->CriterioResultadoService->deleteCriterioResultado($dataset);
                    $response->addNotification(new Notification(Messages::HCM03000_AVL_CRITERIO_APAGADO_SUCESSO, Notification::TYPE_SUCCESS));
                }
            }
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteFaixaCritResult(DTO\Request\DataSet $request, DTO\Response $response){
        $this->dataSourceName = $this->dataSourceNameFaixa;
        parent::delete($request, $response);
    }

    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );
        return $newFilterCriteria;
    }
} 