<?php

namespace HCM\FPA\Registro;

class RegistroSEFIP extends FPARegistro
{

    const SIM = 'S';
    const NAO = 'N';
    const INDICADORCNAE = 'P';
    const INDICADORCNAE_NAO = 'N';

    // Usado no SEFIP.php.
    const CNPJ = '1';
    const CEI = '2';
    const CPF = '3';
    // Registros contendo informacoes sobre empresa e tomador de servico.
    const LISTA_TIPO_REG_EMP = '10,12,13,14,20,21,50,51';
    // Registros contendo informacoes sobre funcionarios.
    const LISTA_TIPO_REG_TRAB = '30, 32';
    // Indicador de recolhimento da GPS - Campo 20 do registro 00
    const IND_REC_GPS_NOPRAZO = '1';
    const IND_REC_GPS_EMATRASO = '2';
    const IND_REC_GPS_NAOGERA = '3';

    const SEFIP_SALARIO_FAMILIA = 1;
    const SEFIP_SALARIO_MATERNIDADE = 2;
    const SEFIP_REM_SEM_13SAL = 3;
    const SEFIP_13SAL_PAGO_MES = 4;
    const SEFIP_REM_BASE_GPS = 5;
    const SEFIP_REM_13SAL_MOV = 6;
    const SEFIP_REM_13SAL_GPS = 7;
    const SEFIP_INSS_MULT_VINCULOS = 8;
    const SEFIP_COMPEN_VLRCORR = 9;
    const SEFIP_VALOR_NF_COOPER = 10;
    const SEFIP_VALOR_RETENCAO = 11;
    const SEFIP_SALARIO_MATERNIDADE_13 = 12;
    const SEFIP_REM_13SAL_MOV_13 = 13;
    const SEFIP_CONTRIB_INSS_DESC = 14;
    const SEFIP_COMPLEM_INSS_13SAL = 15;

    private $_modalidade;
    private $_codigoRecolhimento;
    private $_competencia;
    private $_competencia13;
    private $_idRecolhimentoGPS;
    private $_codPagtoGPS;

//    protected $_tpInscricao;
//    protected $_nrInscricao;


    /**
     * Gera uma chave - Parte comum aos diversos registros.
     *
     * @param string $tpRegistro  Numero do Tipo de Registro.
     * @param string $tpInscricao Numero do Tipo de Inscricao.
     * @param string $nrInscricao Numero da Inscricao.
     *
     * @return void
     * @see FPARegistro::geraRegistro()
     *
     * @author alessandrobartels - 02/06/2011
     */
    protected function geraRegistro($tpRegistro, $tpInscricao, $nrInscricao)
    {
        // Bloco 1 | 001-002 | Tipo do Registro.
        $this->atribuiDado($tpRegistro, 2);

        // Bloco 2 | 003 | Tipo de Inscricao.
        // @todo para empregador so pode aceitar 2.
        $this->atribuiDado($tpInscricao, 1);

        // Bloco 3 | 004-017 | Inscricao da Empresa.
        $this->atribuiDado($nrInscricao, 14, parent::CARACTER_ZERO, self::PREENCHE_ESQUERDA);
    }


    /**
     * Atribui valor a modalidade GFIP.
     *
     * @param string $modalidade Identificador de modalidade de geracao do GFIP.
     *
     * @return void
     *
     * @author alessandrobartels
     */
    public function setModalidade($modalidade)
    {
        $this->_modalidade = $modalidade;
    }


    /**
     * Pega valor da modalidade GFIP.
     *
     * @return string
     *
     * @author alessandrobartels
     */
    public function getModalidade()
    {
        return $this->_modalidade;
    }


    /**
     * Atribui valor a codigo de recolhimento GFIP.
     *
     * @param string $codigo Codigo de recolhimento GFIP.
     *
     * @return void
     *
     * @author alessandrobartels
     */
    public function setCodigoRecolhimento($codigo)
    {
        $this->_codigoRecolhimento = $codigo;
    }


    /**
     * Pega codigo GFIP.
     *
     * @return string
     *
     * @author alessandrobartels
     */
    public function getCodigoRecolhimento()
    {
        return $this->_codigoRecolhimento;
    }


    /**
     * Atribui competencia do GFIP.
     *
     * @param TkDateTime $competencia Competencia (data) do GFIP.
     *
     * @return void
     *
     * @author alessandrobartels
     */
    public function setCompetencia($competencia)
    {
        $this->_competencia = $competencia->format('Y/m');
    }


    /**
     * Pega a competencia do GFIP.
     *
     * @return string
     *
     * @author alessandrobartels
     */
    public function getCompetencia()
    {
        return $this->_competencia;
    }


    /**
     * Atribui identificador de geracao da competencia 13.
     *
     * @param boolean $competencia13 Identificador de geracao da competencia 13.
     *
     * @return void
     *
     * @author alessandrobartels
     */
    public function setCompetencia13($competencia13)
    {
        $this->_competencia13 = $competencia13;
    }


    /**
     * Pega identificador de competencia 13.
     *
     * @return boolean
     *
     * @author alessandrobartels
     */
    public function getCompetencia13()
    {
        return $this->_competencia13;
    }

    /*public function setNrInscricao($nrInscricao){
        $this->_nrInscricao = $nrInscricao;
    }

    public function getNrInscricao(){
        return $this->_nrInscricao;
    }

    public function setTpInscricao($tpInscricao){
        $this->_tpInscricao = $tpInscricao;
    }

    public function getTpInscricao(){
        return $this->_tpInscricao;
    }*/


    /*
    public function determinaInscricao(){

        if ($this->_tpInscResp === self::CNPJ) {
            $this->_nrInscricao = $estrutura->historico->getCdcnpjestrut();
            $this->_tpInscricao = self::CNPJ;
        } elseif ($this->_tpInscResp === self::CEI) {
            $this->_nrInscricao = $estrutura->historico->getCdceiestrut();
            $this->_tpInscricao = self::CEI;
        }
    }
    */

    /**
     * Atribui valor a identificador de recolhimento GPS.
     *
     * @param string $codigo Identificador de recolhimento GPS.
     *
     * @return void
     *
     * @author felipesantos
     */
    public function setIdRecolhimentoGPS($codigo)
    {
        $this->_idRecolhimentoGPS = $codigo;
    }


    /**
     * Pega codigo GFIP.
     *
     * @return string
     *
     * @author alessandrobartels
     */
    public function getIdRecolhimentoGPS()
    {
        return $this->_idRecolhimentoGPS;
    }


    /**
     * Atribui valor a código de pagamento da GPS.
     *
     * @param string $codigo Código de pagamento da GPS.
     *
     * @return void
     *
     * @author felipesantos
     */
    public function setCodPagtoGPS($codigo)
    {
        $this->_codPagtoGPS = $codigo;
    }


    /**
     * Pega codigo GFIP.
     *
     * @return string
     *
     * @author alessandrobartels
     */
    public function getCodPagtoGPS()
    {
        return $this->_codPagtoGPS;
    }

}