<?php

namespace HCM\Geral\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Request;
use HCM\Util\HCMParameters;
use HCM\Util\Repositories;
use HCM\Util\Messages;
use Doctrine\ORM\EntityManager;

class ServicoPATController extends Crud {

    protected $servicoPATService;
    protected $dataSourceName = 'gpe_tiposervpat';
    protected $dataSourceName1 = 'gpe_patvinculo_get';
    protected $entityManager;
    
    protected $parameterBagColumns = array('P_NRORG', 'P_NRORG_PADRAO');
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, HCMParameters $hcmParameters, \HCM\Geral\Services\ServicoPATService $servicoPATService,EntityManager $entityManager){
        $this->parameterBag = $parameterBag;
        $this->hcmParameters = $hcmParameters;
        $this->servicoPATService = $servicoPATService;
        $this->entityManager = $entityManager;
        parent::__construct($dataSourceManager);
    }

    public function getServicoPAT(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function getVinculoPAT(DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceName1);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData);
        $response->addDataSet($dataSet);
    }
    
    public function setServicoPAT(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            foreach ($request->getDataSet()->getRows() as &$row) {
                if (array_key_exists('NRTIPOSERVPAT', $row)) {
                    if ($row['NRTIPOSERVPAT'] === '') {
                       $row['NRTIPOSERVPAT'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'GPE_TIPOSERVPAT', 1, 12, true); 
                    }
                } else {
                    $row['NRTIPOSERVPAT'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'GPE_TIPOSERVPAT', 1, 12, true); 
                }
            }
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function setVinculoPAT(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $this->dataSourceName = "gpe_patvinculo";
            foreach ($request->getDataSet()->getRows() as &$row) {
                if($row['__is_new'] === true){
                    $vinculopat = $this->entityManager->getRepository(Repositories::GPE_PATVINCULO)->findOneBy(array("nrtiposervpat" => $row['NRTIPOSERVPAT'],"nrvinculom" => $row['NRVINCULOM'], "nrorg" => $row['NRORG']));
                    if(isset($vinculopat)){
                        return $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message(Messages::HCM00000_GER_SERVPAT_VINCULO_CADASTRADO_ERROR, DTO\Response\Message::TYPE_ERROR));
                    }
                }   
                if (array_key_exists('NRPATVINCULO', $row)) {
                    if ($row['NRPATVINCULO'] === '') {
                        $row['NRPATVINCULO'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'GPE_PATVINCULO', 1, 12, true); 
                    }
                } else {
                    $row['NRPATVINCULO'] = \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgPadrao(), 'GPE_PATVINCULO', 1, 12, true); 
                }
            }
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteServicoPAT(DTO\Request\DataSet $request, DTO\Response $response){
        try {
            $dataset = $request->getDataSet()->getRows();
            $dataset = $dataset[0];
            $this->servicoPATService->deleteServicoPAT($dataset);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('delete', array(true)));
        } catch(\Exception $e) {
            if ($e->getCode() === 10) {
                $response->addMessage(new \Zeedhi\Framework\DTO\Response\Message($e->getMessage(), DTO\Response\Message::TYPE_ERROR));
            }  
            else {
                $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
 	        }
        }
    }
    
    public function deleteVinculoPAT(DTO\Request\DataSet $request, DTO\Response $response){
        $this->dataSourceName = "gpe_patvinculo";
        parent::delete($request, $response);
    }

    protected function processConditionValue($condition) {
        return $condition['value'];
    }
    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }
        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );
        return $newFilterCriteria;
    }
} 