<?php

namespace HCM\Geral\Entity;

use HCM\Util\Repositories;
use HCM\Util\MsgCalculo;
use HCM\Util\Util;
use HCM\Util\FPA;
use HCM\Util\TkEntity;
use Zeedhi\Framework\Session\Session;
use HCM\Util\DateUtil;
/**
 * Enter description here ...
 *
 * @package Entity
 *
 * @author  alessandrobartels
 */
class GpealtesalarioEntity extends TkEntity
{
    private $_nrOrg;
    private $_dtAux;

    private $_alteracao;
    private $_persiste = false;

    const ALTERACAO_SALARIO_ADMISSAO = 1;
    const ALTERACAO_SALARIO_DISSIDIO = 3;
    const ALTERACAO_SALARIO_CONVENSAO = 5;
    const ALTERACAO_SALARIO_ACORDO = 9;
    
    const IDTPSALARIO_MENSAL = 'MENSAL';
    const IDTPSALARIO_QUINZENAL = 'QUINZENAL';
    const IDTPSALARIO_SEMANAL = 'SEMANAL';
    const IDTPSALARIO_DIARIO = 'DIARIO';
    const IDTPSALARIO_HORA = 'HORA';
    const IDTPSALARIO_TAREFA = 'TAREFA';

    public function __construct($entityManager, $hcmParameters){
        
        $this->_nrOrg = $hcmParameters->getNrorgTrabalho();
        $this->_dtAux = FPA::getDataAtual();
        parent::__construct(null,$entityManager);
    }

    public function retornaAlteSalarioporVinculo($nrvinculom, $nrOrg){
        return Gpealtesalario::retornaAlteSalarioporVinculo($nrvinculom, $nrOrg);
    }


    public function retornaAlteSalarioAtualPorVinculoModalidade(
         $dtAlterSalario, $nrVinculom, $nrModalidade
    ){
        $ultimoDia = DateUtil::truncateString(DateUtil::getUltimoDiaDoMes(substr($dtAlterSalario, 0, 10)));
        $alteSalario = $this->entityManager->getRepository(Repositories::GPE_ALTESALARIO)->retornaAlteSalarioAtualPorVinculoModalidade(
                $this->_nrOrg, $ultimoDia, $nrVinculom, $nrModalidade
            );
        return end($alteSalario);
    }
    
    public function retornaAlteSalarioUltimas(
         $dtAlterSalario, $nrVinculom, $nrmodalidade
    ){
        $ultimoDia = DateUtil::truncateString(DateUtil::getUltimoDiaDoMes(substr($dtAlterSalario, 0, 10)));
        $alteSalario = $this->entityManager->getRepository(Repositories::GPE_ALTESALARIO)->retornaAlteSalarioTodas(
                $this->_nrOrg, $ultimoDia, $nrVinculom, $nrmodalidade);
                
        if($alteSalario){
            $salarioAtual = array_pop($alteSalario);
            $salarioAnterior = array_pop($alteSalario);
            return array($salarioAtual, $salarioAnterior);
        }
        
        return false;
    }
    
    private function _inicializaLista($nrOrg, $nrVinculo) {
        $alteracoes = Gpealtesalario::retornaAlteSalario($nrOrg, $nrVinculo);
        foreach ($alteracoes as $alteracao) {
            $this->addItem($alteracao);
        }
    }

    private function _inicializaListaDataAlteracao($nrOrg, $nrVinculo, $dtAltSalario) {
        $alteracoes = Gpealtesalario::retornaAlteraSalarioPorData($nrOrg, $nrVinculo, $dtAltSalario);
        foreach ($alteracoes as $alteracao) {
            $this->addItem($alteracao);
        }
    }

    public function carregaListaAlteracaoSalario($nrVinculo){
        $itens = $this->getItems();
        if (count($itens) === 0) {
            $this->_inicializaLista($this->_nrOrg, $nrVinculo);
            $itens = $this->getItems();
        }

        return $itens;
    }

    public function carregaListaAlteracaoSalarioData($dtAltSalario, $nrVinculo){
        $itens = $this->getItems();
        if (count($itens) === 0) {
            $this->_inicializaListaDataAlteracao($this->_nrOrg, $nrVinculo, $dtAltSalario);
            $itens = $this->getItems();
        }

        return $itens;
    }

    public function carregaAlteracaoSalario($dtAltSalario, $nrVinculo, $nrModalidade){
        $this->_alteracao = $this->retornaAlteSalarioAtualPorVinculoModalidade(
            $dtAltSalario, $nrVinculo, $nrModalidade
        );
        if (is_object($this->_alteracao) === true) {
            return true;
        } else {
            return false;
        }
    }

    public function getSalario(){
        if (is_object($this->_alteracao) === true) {
            $vrSalario = $this->_alteracao->getVrsalario();
            return $vrSalario;
        }
        return null;
    }

    public function getTipoSalario(){
        if (is_object($this->_alteracao) === true) {
            $tipoSalario = $this->_alteracao->getIdtpsalario();
            return $tipoSalario;
        }

        return null;
    }

    public function getDtalterasalario(){
        if (is_object($this->_alteracao) === true) {
            $dtdissidio = $this->_alteracao->getDtaltesalario();
            return $dtdissidio;
        }

        return null;
    }

    public function getDataBaseDissidio(){
        if (is_object($this->_alteracao) === true) {
            $dtbasedissidio = $this->_alteracao->getDtbasedissidio();
            return $dtbasedissidio;
        }

        return null;
    }

    public function getTipoAlteSal(){
        if (is_object($this->_alteracao) === true) {
            $tipoaltesal = $this->_alteracao->getNrtipoaltera();
            return $tipoaltesal;
        }

        return null;
    }


    public function incluiAlteracaoSalario(
        $nrOrg, $nrVinculom, $vrSalario, $vrPercentual, $vrPercentualReal, $vrDiferencaReal,
        $dtAlteSalario, $nrOcorrencia, $nrTipoAltera, $idTipoSalario, $nrTpModalidade, $dtbasedissidio
    ) {
            $alteracao = new self();
            $alteracao->setNrorg($nrOrg);
            $alteracao->setNrvinculom($nrVinculom);
            $alteracao->setVrsalario($vrSalario);
            $alteracao->setVrpercreal($vrPercentual);
            $alteracao->setVrpercaltera($vrPercentualReal);
            $alteracao->setVrdiferencareal($vrDiferencaReal);
            $alteracao->setDtaltesalario($dtAlteSalario);
            $alteracao->setNrocorrencia($nrOcorrencia);
            $alteracao->setNrtipoaltera($nrTipoAltera);
            $alteracao->setIdtpsalario($idTipoSalario);
            $alteracao->setNrtpmodalidsal($nrTpModalidade);
            $alteracao->setDtbasedissidio($dtbasedissidio);
            $alteracao->setNrorginclusao($nrOrg);
            $alteracao->setDtinclusao(now());
            $alteracao->setCdoperinclusao(\Ambiente::getCdOperador());
            $alteracao->setNrorgultatu($nrOrg);
            $alteracao->setDtultatu(now());
            $alteracao->setCdoperultatu(\Ambiente::getCdOperador());

            $alteracao->persist();
    }


    public function editaAlteracaoSalario(
        $salarioReajustado, $vr_percentual, $vr_percentual_real, $vr_diferenca_real,  $dt_alt_salario,
        $nrModalidade, GpealtesalarioEntity $alteracao
    ){
        try {
            $alteracao->setVrsalario($salarioReajustado);
            $alteracao->setVrpercaltera($vr_percentual);
            $alteracao->setVrpercreal($vr_percentual_real);
            $alteracao->setVrdiferencareal($vr_diferenca_real);
            $alteracao->setDtaltesalario($dt_alt_salario);
            $alteracao->setNrtpmodalidsal($nrModalidade);

            $alteracao->persist();

        }catch (Exception $e) {
            throw $e;
        }
    }


    public function geraAlteracaoSalarial(
        $nrVinculo, $salarioReajustado,  $dt_alt_salario, $vr_percentual, $vr_percentual_real,
        $vr_diferenca_real, $nr_tipo_alteracao, $nrTipoSalario, $nrModalidade, $database
    ) {
        $insere = true;
        $possuiMaiorValor = false;
        $posicao = -1;
        $nr_ocorrencia = 1;

        $this->resetItems();
        $alteracoes_salariais = $this->carregaListaAlteracaoSalario($nrVinculo);

        foreach ($alteracoes_salariais as $key => $alteracao) {
            if ($dt_alt_salario->equals($alteracao->getDtaltesalario(), DateUtil::FORMATO_BRASILEIRO) === true) {
                if ($alteracao->getNrocorrencia() >= $nr_ocorrencia) {
                    $nr_ocorrencia = $alteracao->getNrocorrencia() + 1;
                }
            }
        }
        $this->incluiAlteracaoSalario(
            $this->_nrOrg, $nrVinculo, $salarioReajustado, $vr_percentual, $vr_percentual_real,
            $vr_diferenca_real, $dt_alt_salario, $nr_ocorrencia, $nr_tipo_alteracao, $nrTipoSalario,
            $nrModalidade, $database
        );
    }

    public function persist() {
        try {
            if ($this->_persiste === true) {
                $this->_persiste = false;
                $this->_alteracao->persist();
            } else {
                parent::persist();
            }
        } catch (Exception $e) {
            throw new Exception(
                'Erro na inclusao do novo registro - GPEALTESALARIO'.$e->getMessage(), $code, $previous
            );
        }
    }

    public function setAlteracaoSalario($nrOrg, $nrVinculom, $vrSalario, $vrPercentual, $vrPercentualReal,
                                           $vrDiferencaReal, $dtAlteSalario, $nrOcorrencia, $nrTipoAltera, $idTipoSalario,
                                           $nrTpModalidade)
    {
        $this->setNrorg($nrOrg);
        $this->setNrvinculom($nrVinculom);
        $this->setVrsalario($vrSalario);
        $this->setVrpercreal($vrPercentual);
        $this->setVrpercaltera($vrPercentualReal);
        $this->setVrdiferencareal($vrDiferencaReal);
        $this->setDtaltesalario($dtAlteSalario);
        $this->setNrocorrencia($nrOcorrencia);
        $this->setNrtipoaltera($nrTipoAltera);
        $this->setIdtpsalario($idTipoSalario);
        $this->setNrtpmodalidsal($nrTpModalidade);
    }

    public static function getByNrorgVinculomDataOcorrencia($nrorg, $nrvinculom, $dtaltesalario, $nrocorrencia) {
        $altesalario = self::getEntityByWhere(
            'NRORG = ? AND NRVINCULOM = ? AND DTALTESALARIO = ? AND NROCORRENCIA = ?',
            array($nrorg, $nrvinculom, $dtaltesalario, $nrocorrencia)
        );
        return $altesalario;
    }

}