<?php

namespace HCM\PTO\Controllers;

use Zeedhi\Framework\Controller\Crud;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Request;
use HCM\PTO\Services\AssociacaoSituacaoFrequenciaService;

class AssociacaoSituacaoFrequenciaController extends Crud {

    protected $dataSourceGetAssociacaoSituacaoFrequencia = 'ptoTipoProgOcorrencia_getAssociacaoSituacaoFrequencia';
    protected $dataSourceSetAssociacaoSituacaoFrequencia = 'ptoTipoProgOcorrencia_setAssociacaoSituacaoFrequencia';


    protected $parameterBagColumns = array('NRORG', 'NRORGPADRAO');
    protected $associacaoSituacaoFrequenciaService;
    
    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag, AssociacaoSituacaoFrequenciaService $associacaoSituacaoFrequenciaService){
        $this->parameterBag = $parameterBag;
        $this->associacaoSituacaoFrequenciaService = $associacaoSituacaoFrequenciaService;
        parent::__construct($dataSourceManager);
    }

    public function getAssociacaoSituacaoFrequencia (DTO\Request\Filter $request, DTO\Response $response) {
        $filterData = $request->getFilterCriteria();
        $filterData->setDataSourceName($this->dataSourceGetAssociacaoSituacaoFrequencia);
        $newFilterData = $this->populateParameterBag($filterData);
        $dataSet = $this->dataSourceManager->findBy($newFilterData); 
        $response->addDataSet($dataSet);
    }

    public function setAssociacaoSituacaoFrequencia (DTO\Request\DataSet $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceSetAssociacaoSituacaoFrequencia;
        try{
            foreach($request->getDataSet()->getRows() as $row) {

                if($row['__is_new'] === true){
                    $row['DTINCLUSAO'] = $row['DTATUAL'];
                    $row['CDOPERINCLUSAO'] = $row['CDOPERADOR_LOG'];
                    $row['NRORGINCLUSAO'] = $row['NRORGTRAB'];
                    $row['DTULTATU'] = $row['DTATUAL'];
                    $row['CDOPERULTATU'] = $row['CDOPERADOR_LOG'];
                    $row['NRORGULTATU'] = $row['NRORGTRAB'];
                    $row['NRORG'] = $row['NRORGTRAB'];
                    $row['NRASSOCSITUFREQ'] = \HCM\Util\NovoCodigo::geraCodigo($row['NRORGPADRAO'], 'PTO_TIPOPROGOCORRENCIA', 1, 12, true);
                } else {
                    $row['DTULTATU'] = $row['DTATUAL'];
                    $row['CDOPERULTATU'] = $row['CDOPERADOR_LOG'];
                    $row['NRORGULTATU'] = $row['NRORGTRAB'];
                }
            }
            parent::save($request, $response);
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function deleteAssociacaoSituacaoFrequencia (DTO\Request\Row $row, DTO\Response $response) {
        try{
            $dataSet = new DataSet($this->dataSourceSetAssociacaoSituacaoFrequencia, array($row->getRow()));
            $deletedRows = $this->dataSourceManager->delete($dataSet);

            $response->addDataSet(new DataSet($this->dataSourceSetAssociacaoSituacaoFrequencia, array('type' => 'success', $deletedRows)));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    public function assumirPadroes (DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $dataset = $request->getDataSet();
            $dataset = $dataset->getRows();
            $dataset = $dataset[0];
            $result = $this->associacaoSituacaoFrequenciaService->assumirPadroes($dataset);
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('assumirPadroes', array($result)));
        } catch(\Exception $e) {
            $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }

    protected function processConditionValue($condition) {
        return $condition['value'];
    }

    protected function populateParameterBag(FilterCriteria $filterCriteria) {

        $conditions = array();
        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $this->parameterBagColumns)) {
                $this->parameterBag->set($columnName, $this->processConditionValue($condition));
            } else {
                $conditions[] = $condition;
            }
        }

        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );


        return $newFilterCriteria;
    }
}