<?php

namespace HCM\VAB\Services;

use Doctrine\ORM\EntityManager;
use HCM\Util\HCMParameters;
use HCM\Util\Repositories;
use HCM\Util\DateUtil;

class ValeTransporteService {
    
    protected $linhatransp;
    protected $entityManager;
    protected $hcmParameters;
    
    public function __construct(EntityManager $entityManager, HCMParameters $hcmParameters) {
        $this->entityManager = $entityManager;
        $this->hcmParameters = $hcmParameters;
        $this->vab_valeTransporte = Repositories::VAB_LINHAVINC;
    }
    
     public function setReservaValeTransporte($nrorg, $nrVinculom, $idreserva){
        
        $vablinhavincs = $this->entityManager->getRepository(Repositories::VAB_LINHAVINC)->findOneBy(
            [
                'nrorg'      => $nrorg,
                'nrvinculom' => $nrVinculom
            ]
        );
        if($vablinhavincs){
            foreach ($vablinhavincs as $vablinhavinc){
                
                $vabintegtransphs = $this->entityManager->getRepository(Repositories::VAB_INTEGTRANSPH)->findOneBy(
                    [
                        'nrorg'           => $nrorg,                       
                        'nrtipolinhavinc' => $vablinhavinc->getNrtipolinhavinc(),
                        'nrintegtranspm'  => $vablinhavinc->getNrintegtranspm()
                    ]
                );
                
                if($vabintegtransphs){    
                    foreach ($vabintegtransphs as $vabintegtransph){
                        $vabintegtransph->setIdintegreserva($idreserva);
                        $this->entityManager->persist($vabintegtransph);
                        $this->entityManager->flush();
                    }
                }    
            }
        }    
    }
    
    public function setIdReserva($idreserva, $nrintegtranspm){

        $vabintegtransp = $this->entityManager->getRepository(Repositories::VAB_INTEGTRANSPM)->retornaValeTransporte(
            $nrintegtranspm, 
            $this->hcmParameters->getNrorgTrabalho(), 
            $this->hcmParameters->getNrorgPadrao(), 
            $this->hcmParameters->getDtCompetencia()
        );
        
        $vabintegtransph = $vabintegtransp[0]->historico;

        if($vabintegtransph && $this->hcmParameters->getDtCompetencia() == $vabintegtransph->getDtmescompinteg()->format('d/m/Y')){    
            $vabintegtransph->setIdintegreserva($idreserva);

            $vabintegtransph->setDtultatu(Dateutil::getDataDeString($this->hcmParameters->getDataAtual(), DateUtil::FORMATO_BRASILEIRO, false));
            $vabintegtransph->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
            $vabintegtransph->setCdoperultatu($this->hcmParameters->getCdoperador());

            $this->entityManager->persist($vabintegtransph);
            $this->entityManager->flush();

        }else if( $vabintegtransph && $this->hcmParameters->getDtCompetencia() != $vabintegtransph->getDtmescompinteg()->format('d/m/Y') ){

            $new_vabintegtransph = clone $vabintegtransph;
            
            $new_vabintegtransph->setNrintegtransph( \HCM\Util\NovoCodigo::geraCodigo($this->hcmParameters->getNrorgTrabalho(), 'VAB_INTEGTRANSPH', 1, 22, true) );
            $new_vabintegtransph->setIdintegreserva($idreserva);
            
            $new_vabintegtransph->setDtmescompinteg(Dateutil::getDataDeString($this->hcmParameters->getDtCompetencia(), DateUtil::FORMATO_BRASILEIRO, true));

            $new_vabintegtransph->setDtinclusao(Dateutil::getDataDeString($this->hcmParameters->getDataAtual(), DateUtil::FORMATO_BRASILEIRO, false));
            $new_vabintegtransph->setNrorginclusao($this->hcmParameters->getNrorgTrabalho());
            $new_vabintegtransph->setCdoperinclusao($this->hcmParameters->getCdoperador());

            $new_vabintegtransph->setDtultatu(Dateutil::getDataDeString($this->hcmParameters->getDataAtual(), DateUtil::FORMATO_BRASILEIRO, false));
            $new_vabintegtransph->setNrorgultatu($this->hcmParameters->getNrorgTrabalho());
            $new_vabintegtransph->setCdoperultatu($this->hcmParameters->getCdoperador());

            $this->entityManager->persist($new_vabintegtransph);
            $this->entityManager->flush();
        }    
        
    }
    
    public function retirarValeDaReserva($nrintegtranspm){
        
        $valeIntTransp = $this->entityManager->getRepository(Repositories::VAB_INTEGTRANSPM)->retornaValeTransporte(
            $nrintegtranspm,
            $this->hcmParameters->getNrorgTrabalho(),
            $this->hcmParameters->getNrorgPadrao(),
            $this->hcmParameters->getDtCompetencia()
        );

        if($valeIntTransp){
            foreach($valeIntTransp as $valeIntTrans){
                $valeIntTrans->historico->setIdintegreserva("N");
                $this->entityManager->persist($valeIntTrans->historico);
                $this->entityManager->flush();
            }
        }        
                
    }
    
    public function novo($row, $nrvinculom) {
        try{
            $this->entityManager->beginTransaction();
            $vale = new $this->vab_valeTransporte;
            $nrorg = $this->hcmParameters->getNrorgTrabalho();
            
            $dtinilinhavinc = isset($row['DTINILINHAVINC']) ? DateUtil::getDataDeString($row['DTINILINHAVINC'], DateUtil::FORMATO_BRASILEIRO) : null; 
            $dtfimlinhavinc = isset($row['DTFIMLINHAVINC']) ? DateUtil::getDataDeString($row['DTFIMLINHAVINC'], DateUtil::FORMATO_BRASILEIRO) : null; 
            
            $vale->setNrorg($nrorg);
            $vale->setNrvinculom($nrvinculom);
            $vale->setNrlinhatarifa($row['NRLINHATARIFA']);
            $vale->setNrtipolinhavinc($row['NRTIPOLINHAVINC']);
            $vale->setNrintegtranspm(isset($row['NRINTEGTRANSPM']) && !empty($row['NRINTEGTRANSPM']) ? $row['NRINTEGTRANSPM'] : null);
            $vale->setNrsentidolinha($row['NRSENTIDOLINHA']);
            $vale->setQtlinhatarifa($row['QTLINHATARIFA']);
            $vale->setDtinilinhavinc($dtinilinhavinc);
            $vale->setDtfimlinhavinc($dtfimlinhavinc);
            $vale->setNrlinhavinc(\HCM\Util\NovoCodigo::geraCodigo($nrorg, 'VAB_LINHAVINC', 1, 12, true));
            
            // set auditoria
            $vale->setDtinclusao(DateUtil::getDataAtual());
            $vale->setCdoperinclusao($this->hcmParameters->getCdoperador());
            $vale->setNrorginclusao($nrorg);
            $vale->setDtultatu(DateUtil::getDataAtual());
            $vale->setCdoperultatu($this->hcmParameters->getCdoperador());
            $vale->setNrorgultatu($nrorg);
            $this->entityManager->persist($vale);
            $this->entityManager->flush($vale);
            $this->entityManager->commit();
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }
} 